@@ -12,7 +12,7 @@ use feature ();
 package MooX::Pression;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.019';
+our $VERSION   = '0.020';
 
 use Keyword::Declare;
 use B::Hooks::EndOfScope;
@@ -216,7 +216,7 @@ my $handle_signature_list = sub {
 			$parsed[-1]{type}          = $type;
 			$parsed[-1]{type_is_block} = 1;
 			$sig =~ s/^\Q$type//xs;
-			$sig =~ s/^((?&PerlOWS)) $PPR::GRAMMAR//xs;
+			$sig =~ s/^((?&PerlOWS)) $PPR::GRAMMAR//xso;
 		}
 		elsif ($sig =~ /^(
 			~?(?&PerlBareword)(?&PerlAnonymousArray)?
@@ -237,7 +237,7 @@ my $handle_signature_list = sub {
 			$parsed[-1]{type}          = $type;
 			$parsed[-1]{type_is_block} = 0;
 			$sig =~ s/^\Q$type//xs;
-			$sig =~ s/^((?&PerlOWS)) $PPR::GRAMMAR//xs;
+			$sig =~ s/^((?&PerlOWS)) $PPR::GRAMMAR//xso;
 		}
 		else {
 			$parsed[-1]{type} = 'Any';
@@ -249,7 +249,7 @@ my $handle_signature_list = sub {
 			$parsed[-1]{name} = $name;
 			++$seen_named;
 			$sig =~ s/^\*\Q$name//xs;
-			$sig =~ s/^((?&PerlOWS)) $PPR::GRAMMAR//xs;
+			$sig =~ s/^((?&PerlOWS)) $PPR::GRAMMAR//xso;
 		}
 		elsif ($sig =~ /^((?&PerlVariable)) $PPR::GRAMMAR/xso) {
 			my $name = $1;
@@ -261,13 +261,13 @@ my $handle_signature_list = sub {
 		
 		if ($sig =~ /^\?/) {
 			$parsed[-1]{optional} = 1;
-			$sig =~ s/^((?&PerlOWS)) $PPR::GRAMMAR//xs;
+			$sig =~ s/^\?((?&PerlOWS)) $PPR::GRAMMAR//xso;
 		}
 		elsif ($sig =~ /^=((?&PerlOWS))((?&PerlTerm)) $PPR::GRAMMAR/xso) {
 			my ($ws, $default) = ($1, $2);
 			$parsed[-1]{default} = $default;
 			$sig =~ s/^=\Q$ws$default//xs;
-			$sig =~ s/^((?&PerlOWS)) $PPR::GRAMMAR//xs;
+			$sig =~ s/^((?&PerlOWS)) $PPR::GRAMMAR//xso;
 		}
 		
 		if ($sig) {
@@ -762,79 +762,99 @@ sub import {
 	
 	# `class` keyword
 	#
-	keyword class ('+'? $plus, QualifiedIdentifier $name, '(' $has_sig, SignatureList? $sig, ')', Block $block) {
-		my $return = $me->_handle_package_keyword(class => $name, $block, $has_sig, $sig,  $plus, \%opts);
+	keyword class ('+'? $plus, QualifiedIdentifier $name, '(', SignatureList? $sig, ')', Block $block)
+	:desc(parameterizable class) :prefer {
+		my $return = $me->_handle_package_keyword(class => $name, $block, 1, $sig,  $plus, \%opts);
 	}
-	keyword class ('+'? $plus, QualifiedIdentifier $name, Block $block) {
-		my $return = $me->_handle_package_keyword(class => $name, $block, 0,        undef, $plus, \%opts);
+	keyword class ('+'? $plus, QualifiedIdentifier $name, Block $block)
+	:desc(class) :prefer {
+		my $return = $me->_handle_package_keyword(class => $name, $block, 0, undef, $plus, \%opts);
 	}
-	keyword class ('+'? $plus, QualifiedIdentifier $name) {
-		my $return = $me->_handle_package_keyword(class => $name, '',     0,        undef, $plus, \%opts);
+	keyword class ('+'? $plus, QualifiedIdentifier $name)
+	:desc(class) :prefer {
+		my $return = $me->_handle_package_keyword(class => $name, '',     0, undef, $plus, \%opts);
 	}
-	keyword class ('(' $has_sig, SignatureList? $sig, ')', Block $block) {
-		my $return = $me->_handle_package_keyword(class => undef, $block, $has_sig, $sig,  '',    \%opts);
+	keyword class ('(', SignatureList? $sig, ')', Block $block)
+	:desc(anonymous parameterizable class) {
+		my $return = $me->_handle_package_keyword(class => undef, $block, 1, $sig,  '',    \%opts);
 	}
-	keyword class (Block? $block) {
-		my $return = $me->_handle_package_keyword(class => undef, $block, 0,        undef, '',    \%opts);
+	keyword class (Block? $block)
+	:desc(anonymous class) {
+		my $return = $me->_handle_package_keyword(class => undef, $block, 0, undef, '',    \%opts);
 	}
 
 	# `abstract` keyword
 	#
-	keyword abstract ('class', '+'? $plus, QualifiedIdentifier $name, '(' $has_sig, SignatureList? $sig, ')', Block $block) {
-		my $return = $me->_handle_package_keyword(abstract => $name, $block, $has_sig, $sig,  $plus, \%opts);
+	keyword abstract ('class', '+'? $plus, QualifiedIdentifier $name, '(', SignatureList? $sig, ')', Block $block)
+	:desc(parameterizable abstract class) :prefer {
+		my $return = $me->_handle_package_keyword(abstract => $name, $block, 1, $sig,  $plus, \%opts);
 	}
-	keyword abstract ('class', '+'? $plus, QualifiedIdentifier $name, Block $block) {
-		my $return = $me->_handle_package_keyword(abstract => $name, $block, 0,        undef, $plus, \%opts);
+	keyword abstract ('class', '+'? $plus, QualifiedIdentifier $name, Block $block)
+	:desc(abstract class) :prefer {
+		my $return = $me->_handle_package_keyword(abstract => $name, $block, 0, undef, $plus, \%opts);
 	}
-	keyword abstract ('class', '+'? $plus, QualifiedIdentifier $name) {
-		my $return = $me->_handle_package_keyword(abstract => $name, '',     0,        undef, $plus, \%opts);
+	keyword abstract ('class', '+'? $plus, QualifiedIdentifier $name)
+	:desc(abstract class) :prefer {
+		my $return = $me->_handle_package_keyword(abstract => $name, '',     0, undef, $plus, \%opts);
 	}
-	keyword abstract ('class', '(' $has_sig, SignatureList? $sig, ')', Block $block) {
-		my $return = $me->_handle_package_keyword(abstract => undef, $block, $has_sig, $sig,  '',    \%opts);
+	keyword abstract ('class', '(', SignatureList? $sig, ')', Block $block)
+	:desc(anonymous parameterizable abstract class) {
+		my $return = $me->_handle_package_keyword(abstract => undef, $block, 1, $sig,  '',    \%opts);
 	}
-	keyword abstract ('class', Block? $block) {
-		my $return = $me->_handle_package_keyword(abstract => undef, $block, 0,        undef, '',    \%opts);
+	keyword abstract ('class', Block? $block)
+	:desc(anonymous abstract class) {
+		my $return = $me->_handle_package_keyword(abstract => undef, $block, 0, undef, '',    \%opts);
 	}
 
 	# `role` keyword
 	#
-	keyword role (QualifiedIdentifier $name, '(' $has_sig, SignatureList? $sig, ')', Block $block) {
-		my $return = $me->_handle_package_keyword(role => $name, $block, $has_sig, $sig,  '',    \%opts);
+	keyword role (QualifiedIdentifier $name, '(', SignatureList? $sig, ')', Block $block)
+	:desc(parameterizable role) :prefer {
+		my $return = $me->_handle_package_keyword(role => $name, $block, 1, $sig,  '',    \%opts);
 	}
-	keyword role (QualifiedIdentifier $name, Block $block) {
-		my $return = $me->_handle_package_keyword(role => $name, $block, 0,        undef, '',    \%opts);
+	keyword role (QualifiedIdentifier $name, Block $block)
+	:desc(role) :prefer {
+		my $return = $me->_handle_package_keyword(role => $name, $block, 0, undef, '',    \%opts);
 	}
-	keyword role (QualifiedIdentifier $name) {
-		my $return = $me->_handle_package_keyword(role => $name, '',     0,        undef, '',    \%opts);
+	keyword role (QualifiedIdentifier $name)
+	:desc(role) :prefer {
+		my $return = $me->_handle_package_keyword(role => $name, '',     0, undef, '',    \%opts);
 	}
-	keyword role ('(' $has_sig, SignatureList? $sig, ')', Block $block) {
-		my $return = $me->_handle_package_keyword(role => undef, $block, $has_sig, $sig,  '',    \%opts);
+	keyword role ('(', SignatureList? $sig, ')', Block $block)
+	:desc(anonymous parameterizable role) {
+		my $return = $me->_handle_package_keyword(role => undef, $block, 1, $sig,  '',    \%opts);
 	}
-	keyword role (Block? $block) {
-		my $return = $me->_handle_package_keyword(role => undef, $block, 0,        undef, '',    \%opts);
+	keyword role (Block? $block)
+	:desc(anonymouse role) {
+		my $return = $me->_handle_package_keyword(role => undef, $block, 0, undef, '',    \%opts);
 	}
 
 	# `interface` keyword
 	#
-	keyword interface (QualifiedIdentifier $name, '(' $has_sig, SignatureList? $sig, ')', Block $block) {
-		my $return = $me->_handle_package_keyword(interface => $name, $block, $has_sig, $sig,  '',    \%opts);
+	keyword interface (QualifiedIdentifier $name, '(' $has_sig, SignatureList? $sig, ')', Block $block)
+	:desc(parameterizable interface) :prefer {
+		my $return = $me->_handle_package_keyword(interface => $name, $block, 1, $sig,  '',    \%opts);
 	}
-	keyword interface (QualifiedIdentifier $name, Block $block) {
-		my $return = $me->_handle_package_keyword(interface => $name, $block, 0,        undef, '',    \%opts);
+	keyword interface (QualifiedIdentifier $name, Block $block)
+	:desc(interface) :prefer {
+		my $return = $me->_handle_package_keyword(interface => $name, $block, 0, undef, '',    \%opts);
 	}
-	keyword interface (QualifiedIdentifier $name) {
-		my $return = $me->_handle_package_keyword(interface => $name, '',     0,        undef, '',    \%opts);
+	keyword interface (QualifiedIdentifier $name)
+	:desc(interface) :prefer {
+		my $return = $me->_handle_package_keyword(interface => $name, '',     0, undef, '',    \%opts);
 	}
-	keyword interface ('(' $has_sig, SignatureList? $sig, ')', Block $block) {
-		my $return = $me->_handle_package_keyword(interface => undef, $block, $has_sig, $sig,  '',    \%opts);
+	keyword interface ('(' $has_sig, SignatureList? $sig, ')', Block $block)
+	:desc(anonymous parameterizable interface) {
+		my $return = $me->_handle_package_keyword(interface => undef, $block, 1, $sig,  '',    \%opts);
 	}
-	keyword interface (Block? $block) {
-		my $return = $me->_handle_package_keyword(interface => undef, $block, 0,        undef, '',    \%opts);
+	keyword interface (Block? $block)
+	:desc(anonymous interface) {
+		my $return = $me->_handle_package_keyword(interface => undef, $block, 0, undef, '',    \%opts);
 	}
 
 	# `toolkit` keyword
 	#
-	keyword toolkit (Identifier $tk, '(', QualifiedIdentifier|Comma @imports, ')') {
+	keyword toolkit (Identifier $tk, '(', QualifiedIdentifier|Comma @imports, ')') :desc(toolkit statement) {
 		my @processed_imports;
 		while (@imports) {
 			no warnings 'uninitialized';
@@ -858,136 +878,136 @@ sub import {
 	
 	# `begin` and `end` keywords
 	#
-	keyword begin (Block $code) {
+	keyword begin (Block $code) :desc(begin hook) {
 		sprintf('q[%s]->_begin(sub { my ($package, $kind) = (shift, @_); do %s });', $me, $code);
 	}
-	keyword end (Block $code) {
+	keyword end (Block $code) :desc(end hook) {
 		sprintf('q[%s]->_end(sub { my ($package, $kind) = (shift, @_); do %s });', $me, $code);
 	}
 	
 	# `type_name` keyword
 	#
-	keyword type_name (Identifier $tn) {
+	keyword type_name (Identifier $tn) :desc(type_name statement) {
 		sprintf('q[%s]->_type_name(%s);', $me, B::perlstring($tn));
 	}
 	
 	# `extends` keyword
 	#
-	keyword extends (RoleList $parent) {
+	keyword extends (RoleList $parent) :desc(extends statement) {
 		sprintf('q[%s]->_extends(%s);', $me, $parent->$handle_role_list('class'));
 	}
 	
 	# `with` keyword
 	#
-	keyword with (RoleList $roles) {
+	keyword with (RoleList $roles) :desc(with statement) {
 		sprintf('q[%s]->_with(%s);', $me, $roles->$handle_role_list('role'));
 	}
 	
 	# `requires` keyword
 	#
-	keyword requires (Identifier|Block $name, '(' $has_sig, SignatureList? $sig, ')') {
+	keyword requires (Identifier|Block $name, '(' $has_sig, SignatureList? $sig, ')') :desc(requires statement) {
 		$me->_handle_requires_keyword("$name", $has_sig, $sig);
 	}
-	keyword requires (Identifier|Block $name) {
+	keyword requires (Identifier|Block $name) :desc(requires statement) {
 		$me->_handle_requires_keyword("$name", 0, undef);
 	}
 	
 	# `has` keyword
 	#
-	keyword has ('+'? $plus, '*'?, Identifier $name, '!'? $postfix) {
+	keyword has ('+'? $plus, '*'?, Identifier $name, '!'? $postfix) :desc(attribute definition) {
 		$me->_handle_has_keyword("$plus$name$postfix", undef, undef);
 	}
-	keyword has ('+'? $plus, '*'?, Identifier $name, '!'? $postfix, '(', List $spec, ')') {
+	keyword has ('+'? $plus, '*'?, Identifier $name, '!'? $postfix, '(', List $spec, ')') :desc(attribute definition) {
 		$me->_handle_has_keyword("$plus$name$postfix", $spec, undef);
 	}
-	keyword has (Block $name, '(', List $spec, ')') {
+	keyword has (Block $name, '(', List $spec, ')') :desc(attribute definition) {
 		$me->_handle_has_keyword($name, $spec, undef);
 	}
-	keyword has (Block $name) {
+	keyword has (Block $name) :desc(attribute definition) {
 		$me->_handle_has_keyword($name, undef, undef);
 	}
-	keyword has ('+'? $plus, '*'?, Identifier $name, '!'? $postfix, '=', ListElem $default) {
+	keyword has ('+'? $plus, '*'?, Identifier $name, '!'? $postfix, '=', ListElem $default) :desc(attribute definition) {
 		$me->_handle_has_keyword("$plus$name$postfix", undef, $default);
 	}
-	keyword has ('+'? $plus, '*'?, Identifier $name, '!'? $postfix, '(', List $spec, ')', '=', ListElem $default) {
+	keyword has ('+'? $plus, '*'?, Identifier $name, '!'? $postfix, '(', List $spec, ')', '=', ListElem $default) :desc(attribute definition) {
 		$me->_handle_has_keyword("$plus$name$postfix", $spec, $default);
 	}
-	keyword has (Block $name, '(', List $spec, ')', '=', ListElem $default) {
+	keyword has (Block $name, '(', List $spec, ')', '=', ListElem $default) :desc(attribute definition) {
 		$me->_handle_has_keyword($name, $spec, $default);
 	}
-	keyword has (Block $name, '=', ListElem $default) {
+	keyword has (Block $name, '=', ListElem $default) :desc(attribute definition) {
 		$me->_handle_has_keyword($name, undef, $default);
 	}
 	
 	# `constant` keyword
 	#
-	keyword constant (Identifier $name, '=', Expr $value) {
+	keyword constant (Identifier $name, '=', Expr $value) :desc(constant definition) {
 		sprintf('q[%s]->_constant(%s, %s);', $me, B::perlstring($name), $value);
 	}
 	
 	# `method` keyword
 	#
-	keyword method (Identifier|Block $name, MyAttribute? @attrs, '(' $has_sig, SignatureList? $sig, ')', Block $code) {
-		$me->_handle_method_keyword($name, $code, $has_sig, $sig, \@attrs);
+	keyword method (Identifier|Block $name, MyAttribute? @attrs, '(', SignatureList? $sig, ')', Block $code) :desc(method) :prefer {
+		$me->_handle_method_keyword($name, $code, 1, $sig,  \@attrs);
 	}
-	keyword method (Identifier|Block $name, MyAttribute? @attrs, Block $code) {
-		$me->_handle_method_keyword($name, $code, undef, undef, \@attrs);
+	keyword method (Identifier|Block $name, MyAttribute? @attrs, Block $code) :desc(method) :prefer {
+		$me->_handle_method_keyword($name, $code, 0, undef, \@attrs);
 	}
-	keyword method (                        MyAttribute? @attrs, '(' $has_sig, SignatureList? $sig, ')', Block $code) {
-		$me->_handle_method_keyword(undef, $code, $has_sig, $sig, \@attrs);
+	keyword method (                        MyAttribute? @attrs, '(', SignatureList? $sig, ')', Block $code) :desc(anonymous method) {
+		$me->_handle_method_keyword(undef, $code, 1, $sig,  \@attrs);
 	}
-	keyword method (                        MyAttribute? @attrs, Block $code) {
-		$me->_handle_method_keyword(undef, $code, undef, undef, \@attrs);
+	keyword method (                        MyAttribute? @attrs, Block $code) :desc(anonymous method) {
+		$me->_handle_method_keyword(undef, $code, 0, undef, \@attrs);
 	}
 
 	# `multi method` keyword
 	#
-	keyword multi ('method', Identifier|Block $name, MyAttribute? @attrs, '(' $has_sig, SignatureList? $sig, ')', Block $code) {
-		$me->_handle_multimethod_keyword($name, $code, $has_sig, $sig, \@attrs);
+	keyword multi ('method', Identifier|Block $name, MyAttribute? @attrs, '(', SignatureList? $sig, ')', Block $code) :desc(multimethod) {
+		$me->_handle_multimethod_keyword($name, $code, 1, $sig,  \@attrs);
 	}
-	keyword multi ('method', Identifier|Block $name, MyAttribute? @attrs, Block $code) {
-		$me->_handle_multimethod_keyword($name, $code, undef, undef, \@attrs);
+	keyword multi ('method', Identifier|Block $name, MyAttribute? @attrs, Block $code) :desc(multimethod) {
+		$me->_handle_multimethod_keyword($name, $code, 0, undef, \@attrs);
 	}
 
 	# `before`, `after`, and `around` keywords
 	#
-	keyword before (Identifier|Block $name, MyAttribute? @attrs, '(' $has_sig, SignatureList? $sig, ')', Block $code) {
-		$me->_handle_modifier_keyword(before => $name, $code, $has_sig, $sig, \@attrs);
+	keyword before (Identifier|Block $name, MyAttribute? @attrs, '(', SignatureList? $sig, ')', Block $code) :desc(method modifier) {
+		$me->_handle_modifier_keyword(before => $name, $code, 1, $sig,  \@attrs);
 	}
-	keyword before (Identifier|Block $name, MyAttribute? @attrs, Block $code) {
-		$me->_handle_modifier_keyword(before => $name, $code, undef, undef, \@attrs);
+	keyword before (Identifier|Block $name, MyAttribute? @attrs, Block $code) :desc(method modifier) {
+		$me->_handle_modifier_keyword(before => $name, $code, 0, undef, \@attrs);
 	}
-	keyword after (Identifier|Block $name, MyAttribute? @attrs, '(' $has_sig, SignatureList? $sig, ')', Block $code) {
-		$me->_handle_modifier_keyword(after => $name, $code, $has_sig, $sig, \@attrs);
+	keyword after (Identifier|Block $name, MyAttribute? @attrs, '(', SignatureList? $sig, ')', Block $code) :desc(method modifier) {
+		$me->_handle_modifier_keyword(after => $name, $code, 1, $sig,  \@attrs);
 	}
-	keyword after (Identifier|Block $name, MyAttribute? @attrs, Block $code) {
-		$me->_handle_modifier_keyword(after => $name, $code, undef, undef, \@attrs);
+	keyword after (Identifier|Block $name, MyAttribute? @attrs, Block $code) :desc(method modifier) {
+		$me->_handle_modifier_keyword(after => $name, $code, 0, undef, \@attrs);
 	}
-	keyword around (Identifier|Block $name, MyAttribute? @attrs, '(' $has_sig, SignatureList? $sig, ')', Block $code) {
-		$me->_handle_modifier_keyword(around => $name, $code, $has_sig, $sig, \@attrs);
+	keyword around (Identifier|Block $name, MyAttribute? @attrs, '(', SignatureList? $sig, ')', Block $code) :desc(method modifier) {
+		$me->_handle_modifier_keyword(around => $name, $code, 1, $sig,  \@attrs);
 	}
-	keyword around (Identifier|Block $name, MyAttribute? @attrs, Block $code) {
-		$me->_handle_modifier_keyword(around => $name, $code, undef, undef, \@attrs);
+	keyword around (Identifier|Block $name, MyAttribute? @attrs, Block $code) :desc(method modifier) {
+		$me->_handle_modifier_keyword(around => $name, $code, 0, undef, \@attrs);
 	}
 	
 	# `factory` keyword
 	#
-	keyword factory (Identifier|Block $name, MyAttribute? @attrs, '(' $has_sig, SignatureList? $sig, ')', Block $code) {
-		$me->_handle_factory_keyword($name, undef, $code, $has_sig, $sig, \@attrs);
+	keyword factory (Identifier|Block $name, MyAttribute? @attrs, '(', SignatureList? $sig, ')', Block $code) :desc(factory method) {
+		$me->_handle_factory_keyword($name, undef, $code, 1, $sig,  \@attrs);
 	}
-	keyword factory (Identifier|Block $name, MyAttribute? @attrs, Block $code) {
-		$me->_handle_factory_keyword($name, undef, $code, undef, undef,  \@attrs);
+	keyword factory (Identifier|Block $name, MyAttribute? @attrs, Block $code) :desc(factory method) {
+		$me->_handle_factory_keyword($name, undef, $code, 0, undef,  \@attrs);
 	}
-	keyword factory (Identifier|Block $name, 'via', Identifier $via) {
+	keyword factory (Identifier|Block $name, 'via', Identifier $via) :desc(proxy factory method) {
 		$me->_handle_factory_keyword($name, $via, undef, undef, undef, []);
 	}
-	keyword factory (Identifier|Block $name) {
+	keyword factory (Identifier|Block $name) :desc(proxy factory method) {
 		$me->_handle_factory_keyword($name, 'new', undef, undef, undef, []);
 	}
 	
 	# `coerce` keyword
 	#
-	keyword coerce ('from'?, Block|QualifiedIdentifier|String $from, 'via', Block|Identifier|String $via, Block? $code) {
+	keyword coerce ('from'?, Block|QualifiedIdentifier|String $from, 'via', Block|Identifier|String $via, Block? $code) :desc(coercion) {
 		if ($from =~ /^\{/) {
 			$from = "scalar(do $from)"
 		}
@@ -1131,7 +1151,7 @@ sub _modifier {
 #{
 #	package MooX::Pression::Anonymous::Package;
 #	our $AUTHORITY = 'cpan:TOBYINK';
-#	our $VERSION   = '0.019';
+#	our $VERSION   = '0.020';
 #	use overload q[""] => sub { ${$_[0]} }, fallback => 1;
 #	sub DESTROY {}
 #	sub AUTOLOAD {
@@ -1142,7 +1162,7 @@ sub _modifier {
 #	
 #	package MooX::Pression::Anonymous::Class;
 #	our $AUTHORITY = 'cpan:TOBYINK';
-#	our $VERSION   = '0.019';
+#	our $VERSION   = '0.020';
 #	our @ISA       = qw(MooX::Pression::Anonymous::Package);
 #	sub new {
 #		my $me = shift;
@@ -1155,12 +1175,12 @@ sub _modifier {
 #	
 #	package MooX::Pression::Anonymous::Role;
 #	our $AUTHORITY = 'cpan:TOBYINK';
-#	our $VERSION   = '0.019';
+#	our $VERSION   = '0.020';
 #	our @ISA       = qw(MooX::Pression::Anonymous::Package);
 #	
 #	package MooX::Pression::Anonymous::ParameterizableClass;
 #	our $AUTHORITY = 'cpan:TOBYINK';
-#	our $VERSION   = '0.019';
+#	our $VERSION   = '0.020';
 #	our @ISA       = qw(MooX::Pression::Anonymous::Package);
 #	sub generate_package {
 #		my $me  = shift;
@@ -1174,7 +1194,7 @@ sub _modifier {
 #
 #	package MooX::Pression::Anonymous::ParameterizableRole;
 #	our $AUTHORITY = 'cpan:TOBYINK';
-#	our $VERSION   = '0.019';
+#	our $VERSION   = '0.020';
 #	our @ISA       = qw(MooX::Pression::Anonymous::Package);
 #	sub generate_package {
 #		my $me  = shift;
@@ -3004,6 +3024,9 @@ fine with them, but some things won't work, like plugins that rely on
 being able to wrap C<has>. So it would be nice to have a plugin system
 that extensions can hook into.
 
+If you're interested in extending MooX::Pression, file a bug report about
+it and let's have a conversation about the best way for that to happen.
+
 =head1 SEE ALSO
 
 Less magic version:
